#!/usr/bin/env python3
# -*- coding: latin-1 -*-
"""Assign AWS SSO Permission Sets to multiple accounts."""

from . import helper_aws_sso
from . import helper_common
from . import helper_aws_entrypoint
from .helper_parameters import *
from multithreader import threads
from pprint import pprint as pp


def aws_sso_assign():
    """Assign AWS SSO Permission Sets."""
    # Enter AWS environment.
    session = helper_aws_entrypoint.auth()
    sso_admin = session.client(
        'sso-admin',
        region_name=region
    )

    # Create accounts list from JSON file.
    data = helper_common.read_json(sso_assign_input_file)
    account_ids = [account['account_id'] for account in data]

    # Execute task with multithreading.
    items = {
        'sso_admin': sso_admin,
        'sso_instance_arn': sso_instance_arn,
        'data': data
    }
    results = threads(
        helper_aws_sso.assign_permission_sets_dry_run,
        account_ids,
        items
    ) if DRY_RUN else threads(
        helper_aws_sso.assign_permission_sets,
        account_ids,
        items
    )

    # Print results.
    pp(results)


def main():
    """Execute main function."""
    aws_sso_assign()


if __name__ == '__main__':
    main()



#!/usr/bin/env python3
# -*- coding: latin-1 -*-
"""Provide AWS auth and crawler options."""

from .helper_parameters import *
import aws_crawler
from aws_authenticator import AWSAuthenticator as awsauth


def auth():
    """Login to AWS."""
    if auth_method == 'profile':
        auth = awsauth(
            profile_name=profile_name,
        )
        session = auth.profile()
    elif auth_method == 'iam':
        auth = awsauth(
            access_key_id=access_key_id,
            secret_access_key=secret_access_key,
        )
        session = auth.iam()
    elif auth_method == 'sso':
        auth = awsauth(
            sso_url=sso_url,
            sso_role_name=sso_role_name,
            sso_account_id=sso_account_id
        )
        session = auth.sso()
    else:
        raise ValueError('auth_method is not defined.')
    return session


def crawler(session) -> list:
    """Create AWS account list."""
    if accounts_list_src == 'accounts':
        account_ids = aws_crawler.create_account_list(
            accounts
        )
    elif accounts_list_src == 'ou':
        account_ids = aws_crawler.list_ou_accounts(
            session,
            ou
        )
    elif accounts_list_src == 'statuses':
        account_ids = aws_crawler.list_accounts(
            session,
            statuses
        )
    else:
        raise ValueError('accounts_list_src is not defined.')
    return account_ids


def main():
    """Execute main function."""
    pass


if __name__ == '__main__':
    main()
